Patterns — Grid

This is a twelve column section in a row. Each of these includes a div.panel element so you can see where the columns are - it's not required at all for the grid.

Six columns

Six columns

Four columns

Four columns

Four columns

### How does it work?

The grid is built up out of row and columns. When you resize your browser window to the size of a mobile device, all adjacent columns are positioned underneath each other.

To use this grid in your websites, please follow the guidelines in the document below.